import React from 'react'
import  './areachart.css';
import ReactApexChart from 'react-apexcharts';
import PropTypes from 'prop-types';

function Areachart({color,xaxisdata,yaxisdata,smoothline,xyaxisdatahidden,height,showgrid}) {

    const options = {
        chart: {
            type: 'area',
            height: height ||  250,
            sparkline: {
              enabled: true
            },
            zoom: {
              enabled: false
            },
          },
          dataLabels: {
            enabled: false
          },
          colors: [color],
          stroke: {
            curve: smoothline ? 'smooth'  : 'straight',
            width: 2,
          },
          xaxis: {
            categories: xaxisdata,
            labels: {
              show: xyaxisdatahidden ? false : true,
                style: {
                    colors: "rgba(16, 31, 79, 0.45)",
                    fontSize: '12px',
                },
            },
            axisBorder: {
              show: xyaxisdatahidden ? false : true,
            }
          },
          legend: {
            horizontalAlign: 'left'
          },
          fill: {
            colors: color,
            gradient: {
                shade: 'light',
                type: "vertical",
                shadeIntensity: 0.2,
                opacityFrom:.5,
                opacityTo: 0,
            },
          },
          chart: {
            toolbar: {
              show: false,
            }
        },
        yaxis: {
            labels: {
              show: xyaxisdatahidden ? false : true,
                style: {
                    colors: "rgba(16, 31, 79, 0.45)",
                    fontSize: '12px',
                },
            },
            axisBorder: {
              show: xyaxisdatahidden ? false : true,
            }
        },
        grid: {
            show:showgrid ? true : false,
            borderColor: 'rgba(16, 31, 79, 0.08)',
            
        }
    }

    const series = [{
        name: "",
        data:yaxisdata
    }]


    return (
        <div className="areachart">
            <ReactApexChart options={options} series={series} type="area" height={height || 250} />
        </div>
    )
}


Areachart.propTypes = {
    color: PropTypes.string,
    xaxisdata:PropTypes.array.isRequired,
    yaxisdata:PropTypes.array.isRequired,
    height:PropTypes.number,
    smoothline:PropTypes.bool,
    xyaxisdatahidden:PropTypes.bool,
};

Areachart.defaultProps = {
    color: "#007BFF",
    height: '',
    smoothline:false,
    xyaxisdatahidden:false
};


export default Areachart
